@@ -14,10 +14,10 @@ class SignalChannel:
     __slots__ = ('_signals', '_queue')
 
     def __init__(self) -> None:
-        self._signals: typing.List[int] = []
-        self._queue: asyncio.Queue[int] = asyncio.Queue()
+        self._signals: typing.List[signal.Signals] = []
+        self._queue: asyncio.Queue[signal.Signals] = asyncio.Queue()
 
-    def add_signal(self, signum: int) -> Self:
+    def add_signal(self, signum: signal.Signals) -> Self:
         if signum not in signal.valid_signals():
             raise TypeError(f'Invalid signal: {signum}')
 
@@ -31,16 +31,16 @@ class SignalChannel:
         signals = ', '.join(repr(sig) for sig in self._signals)
         return f'<SignalChannel ({signals})>'
 
-    def send(self, signum: int) -> None:
+    def send(self, signum: signal.Signals) -> None:
         if signum not in signal.valid_signals():
             raise TypeError(f'Invalid signal: {signum}')
 
         if signum in self._signals:
             self._queue.put_nowait(signum)
 
-    async def receive(self) -> int:
+    async def receive(self) -> signal.Signals:
         return await self._queue.get()
 
-    async def __aiter__(self) -> typing.AsyncIterator[int]:
+    async def __aiter__(self) -> typing.AsyncIterator[signal.Signals]:
         while True:
             yield await self._queue.get()
